@@ -67,11 +67,11 @@ KIconConfig::KIconConfig(const KComponentData &inst, QWidget *parent)
 
     QPushButton *push;
 
-    push = addPreviewIcon(0, i18n("Default"), this, g_lay);
+    push = addPreviewIcon(0, i18nc("@label The icon rendered by default", "Default"), this, g_lay);
     connect(push, SIGNAL(clicked()), SLOT(slotEffectSetup0()));
-    push = addPreviewIcon(1, i18n("Active"), this, g_lay);
+    push = addPreviewIcon(1, i18nc("@label The icon rendered as active", "Active"), this, g_lay);
     connect(push, SIGNAL(clicked()), SLOT(slotEffectSetup1()));
-    push = addPreviewIcon(2, i18n("Disabled"), this, g_lay);
+    push = addPreviewIcon(2, i18nc("@label The icon rendered as disabled", "Disabled"), this, g_lay);
     connect(push, SIGNAL(clicked()), SLOT(slotEffectSetup2()));
 
     m_pTab1 = new QWidget(this);
@@ -94,13 +94,10 @@ KIconConfig::KIconConfig(const KComponentData &inst, QWidget *parent)
     lbl->setBuddy(mpSizeBox);
     grid->addWidget(mpSizeBox, 0, 1, Qt::AlignLeft);
 
-    mpDPCheck = new QCheckBox(i18n("Double-sized pixels"), m_pTab1);
-    connect(mpDPCheck, SIGNAL(toggled(bool)), SLOT(slotDPCheck(bool)));
-    grid->addWidget(mpDPCheck, 1, 0, 1, 2, Qt::AlignLeft);
-
     mpAnimatedCheck = new QCheckBox(i18n("Animate icons"), m_pTab1);
     connect(mpAnimatedCheck, SIGNAL(toggled(bool)), SLOT(slotAnimatedCheck(bool)));
     grid->addWidget(mpAnimatedCheck, 2, 0, 1, 2, Qt::AlignLeft);
+    grid->setRowStretch(3, 10);
 
     top->activate();
 
@@ -138,7 +135,7 @@ void KIconConfig::init()
 	mbChanged[i] = false;
 
     // Fill list/checkboxen
-    mpUsageList->addItem(i18n("Desktop/File Manager"));
+    mpUsageList->addItem(i18n("Desktop"));
     mpUsageList->addItem(i18n("Toolbar"));
     mpUsageList->addItem(i18n("Main Toolbar"));
     mpUsageList->addItem(i18n("Small Icons"));
@@ -179,9 +176,8 @@ void KIconConfig::initDefaults()
 
     KIconLoader::Group i;
     QStringList::ConstIterator it;
-    for(it=mGroups.begin(), i=KIconLoader::FirstGroup; it!=mGroups.end(); ++it, i++)
+    for(it=mGroups.constBegin(), i=KIconLoader::FirstGroup; it!=mGroups.constEnd(); ++it, i++)
     {
-	mbDP[i] = false;
 	mbChanged[i] = true;
 	mbAnimated[i] = false;
 	if (mpLoader->theme())
@@ -241,16 +237,15 @@ void KIconConfig::read()
 
     int i, j, effect;
     QStringList::ConstIterator it, it2;
-    for (it=mGroups.begin(), i=0; it!=mGroups.end(); ++it, i++)
+    for (it=mGroups.constBegin(), i=0; it!=mGroups.constEnd(); ++it, i++)
     {
         mbChanged[i] = false;
 
         KConfigGroup iconGroup(mpConfig, *it + "Icons");
 	mSizes[i] = iconGroup.readEntry("Size", mSizes[i]);
-	mbDP[i] = iconGroup.readEntry("DoublePixels", mbDP[i]);
 	mbAnimated[i] = iconGroup.readEntry("Animated", mbAnimated[i]);
 
-	for (it2=mStates.begin(), j=0; it2!=mStates.end(); ++it2, j++)
+	for (it2=mStates.constBegin(), j=0; it2!=mStates.constEnd(); ++it2, j++)
 	{
 	    QString tmp = iconGroup.readEntry(*it2 + "Effect", QString());
 	    if (tmp == "togray")
@@ -300,7 +295,6 @@ void KIconConfig::apply()
             mpSizeBox->setCurrentIndex(index);
             mSizes[mUsage] = size; // best or exact match
         }
-        mpDPCheck->setChecked(mbDP[mUsage]);
         mpAnimatedCheck->setChecked(mbAnimated[mUsage]);
     }
 }
@@ -314,11 +308,6 @@ void KIconConfig::preview(int i)
 
     QPixmap pm = mpLoader->loadIcon(mExample, KIconLoader::NoGroup, mSizes[viewedGroup]);
     QImage img = pm.toImage();
-    if (mbDP[viewedGroup])
-    {
-	int w = img.width() * 2;
-	img = img.scaled(w, w, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-    }
 
     Effect &effect = mEffects[viewedGroup][i];
 
@@ -350,13 +339,12 @@ void KIconConfig::save()
 {
     int i, j;
     QStringList::ConstIterator it, it2;
-    for (it=mGroups.begin(), i=0; it!=mGroups.end(); ++it, i++)
+    for (it=mGroups.constBegin(), i=0; it!=mGroups.constEnd(); ++it, i++)
     {
 	KConfigGroup cg(mpConfig, *it + "Icons");
 	cg.writeEntry("Size", mSizes[i], KConfig::Normal|KConfig::Global);
-	cg.writeEntry("DoublePixels", mbDP[i], KConfig::Normal|KConfig::Global);
 	cg.writeEntry("Animated", mbAnimated[i], KConfig::Normal|KConfig::Global);
-	for (it2=mStates.begin(), j=0; it2!=mStates.end(); ++it2, j++)
+	for (it2=mStates.constBegin(), j=0; it2!=mStates.constEnd(); ++it2, j++)
 	{
 	    QString tmp;
 	    switch (mEffects[i][j].type)
@@ -381,7 +369,7 @@ void KIconConfig::save()
 		break;
 	    }
 	    cg.writeEntry(*it2 + "Effect", tmp, KConfig::Normal|KConfig::Global);
-	    cg.writeEntry(*it2 + "Value", int(mEffects[i][j].value), KConfig::Normal|KConfig::Global);
+	    cg.writeEntry(*it2 + "Value", mEffects[i][j].value, KConfig::Normal|KConfig::Global);
             cg.writeEntry(*it2 + "Color", mEffects[i][j].color, KConfig::Normal|KConfig::Global);
             cg.writeEntry(*it2 + "Color2", mEffects[i][j].color2, KConfig::Normal|KConfig::Global);
             cg.writeEntry(*it2 + "SemiTransparent", mEffects[i][j].transparent, KConfig::Normal|KConfig::Global);
@@ -420,13 +408,11 @@ void KIconConfig::slotUsage(int index)
     if ( mUsage == KIconLoader::Panel || mUsage == KIconLoader::LastGroup )
     {
         mpSizeBox->setEnabled(false);
-        mpDPCheck->setEnabled(false);
 	mpAnimatedCheck->setEnabled( mUsage == KIconLoader::Panel );
     }
     else
     {
         mpSizeBox->setEnabled(true);
-        mpDPCheck->setEnabled(true);
 	mpAnimatedCheck->setEnabled( mUsage == KIconLoader::Desktop );
     }
 
@@ -440,11 +426,6 @@ void KIconConfig::EffectSetup(int state)
 
     QPixmap pm = mpLoader->loadIcon(mExample, KIconLoader::NoGroup, mSizes[viewedGroup]);
     QImage img = pm.toImage();
-    if (mbDP[viewedGroup])
-    {
-	int w = img.width() * 2;
-	img = img.scaled(w, w, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-    }
 
     QString caption;
     switch (state)
@@ -489,19 +470,6 @@ void KIconConfig::slotSize(int index)
     mbChanged[mUsage] = true;
 }
 
-void KIconConfig::slotDPCheck(bool check)
-{
-    Q_ASSERT(mUsage < KIconLoader::LastGroup);
-    if (mbDP[mUsage] != check)
-    {
-        mbDP[mUsage] = check;
-        emit changed(true);
-        mbChanged[mUsage] = true;
-    }
-    preview();
-
-}
-
 void KIconConfig::slotAnimatedCheck(bool check)
 {
     Q_ASSERT(mUsage < KIconLoader::LastGroup);
