@@ -21,27 +21,20 @@
 #ifndef SINKITEM_H
 #define SINKITEM_H
 
-#include "widgetrectitem.h"
 #include <Phonon/MediaNode>
+#include <QtGui/QWidget>
 
 using Phonon::MediaNode;
 
-class SinkItem : public WidgetRectItem
+class SinkItem : public QWidget
 {
+    Q_OBJECT
     public:
-        enum { Type = UserType + 3 };
-        int type() const { return Type; }
-
         virtual MediaNode *mediaNode() = 0;
         virtual const MediaNode *mediaNode() const = 0;
 
     protected:
-        SinkItem(QGraphicsItem *parent, QGraphicsView *widget)
-            : WidgetRectItem(parent, widget)
-        {}
-        SinkItem(const QPoint &pos, QGraphicsView *widget)
-            : WidgetRectItem(pos, widget)
-        {}
+        SinkItem() {}
 };
 
 #endif // SINKITEM_H
